@@ -48,7 +48,7 @@ def generate_paragraphs_graph(paragraphs: list[Paragraph]) -> list[list[int]]:
     nodes = [Node(i) for i in range(num_nodes)]
     graph = Graph(nodes)
     for i in range(num_nodes):
-         for j in range(i + 1, num_nodes):
+        for j in range(i + 1, num_nodes):
             relation = paragraph_comparator(paragraphs[i], paragraphs[j])
             if relation == 1:
                 nodes[i].add_neighbor(nodes[j])
@@ -63,5 +63,5 @@ def sort_paragraphs(paragraphs: list[Paragraph]) -> list[Paragraph]:
     """
     graph = generate_paragraphs_graph(paragraphs)
     sorted_nodes = graph.topological_sort()
-    sorted_paragraphs = [paragraphs[node.index] for node in sorted_nodes]
+    sorted_paragraphs = [paragraphs[node.data] for node in sorted_nodes]
     return sorted_paragraphs
